@@ -25,7 +25,7 @@ urlpatterns = patterns('imagestore.views',
 
                        url(r'^tag/(?P<tag>[^/]+)/$', ImageListView.as_view(), name='tag'),
 
-                       url(r'^user/(?P<username>\w+)/albums', AlbumListView.as_view(), name='user'),
+                       url(r'^user/(?P<username>\w+)/albums/', AlbumListView.as_view(), name='user'),
                        url(r'^user/(?P<username>\w+)/$', ImageListView.as_view(), name='user-images'),
 
                        url(r'^upload/$', CreateImage.as_view(), name='upload'),
